@@ -946,10 +946,11 @@ class Network(util.DaemonThread):
             self.process_responses(interface)
 
     def init_headers_file(self):
-        filename = self.blockchains[0].path()
-        if os.path.exists(filename):
+        b = self.blockchains[0]
+        if b.get_hash(0) == bitcoin.GENESIS:
             self.downloading_headers = False
             return
+        filename = b.path()
         def download_thread():
             try:
                 import urllib, socket
